==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectNumber.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnumber_h
#define objectnumber_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_number_enumeration_scalingunit_1,
  adms_number_enumeration_scalingunit_A,
  adms_number_enumeration_scalingunit_D,
  adms_number_enumeration_scalingunit_E,
  adms_number_enumeration_scalingunit_G,
  adms_number_enumeration_scalingunit_M,
  adms_number_enumeration_scalingunit_P,
  adms_number_enumeration_scalingunit_T,
  adms_number_enumeration_scalingunit_a,
  adms_number_enumeration_scalingunit_c,
  adms_number_enumeration_scalingunit_d,
  adms_number_enumeration_scalingunit_f,
  adms_number_enumeration_scalingunit_h,
  adms_number_enumeration_scalingunit_k,
  adms_number_enumeration_scalingunit_m,
  adms_number_enumeration_scalingunit_n,
  adms_number_enumeration_scalingunit_p,
  adms_number_enumeration_scalingunit_u
} e_number_scalingunit;
win32_interface char* adms_number_tostring_scalingunit_impl (p_admsttransform myadmsttransform,e_number_scalingunit e);
win32_interface e_number_scalingunit adms_number_fromstring_scalingunit_impl (p_admsttransform myadmsttransform,char*token);
struct s_number {
  t_subexpression _subexpression;
  char* _value;
  int _value_isdefault : 1;
  e_number_scalingunit _scalingunit;
  int _scalingunit_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_number_getuid (p_number mynumber);
win32_interface gboolean adms_number_cmp (p_number mynumber,p_number refnumber);
win32_interface p_number adms_number_new_1 (char* myvalue);
#define adms_number_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_number_free(item)\
{\
  free(item->_value);\
  free(item);\
}
win32_interface p_adms adms_number_new_impl (p_adms arguments[]);
win32_interface p_number adms_number_impl (void* member);
#define adms_number(member) ((p_number) (member))
#define adms_number_new adms_number_new_1
#define adms_number_isdefault_value(number) (adms_number(number)->_value_isdefault)
#define adms_number_valueof_value(number) (adms_number(number)->_value)
#define adms_number_isdefault_scalingunit(number) (adms_number(number)->_scalingunit_isdefault)
#define adms_number_valueof_scalingunit(number) (adms_number(number)->_scalingunit)
#define adms_number_valueof_subexpression(number) ((p_subexpression)number)
#define adms_number_valueof_math(number) ((p_math)number)
#define adms_number_valueof_adms(number) ((p_adms)number)
#define adms_number_valueto_value(a,b) ((p_number)a)->_value=(b)
win32_interface void adms_number_valueto_value_impl (p_number mynumber,char* _value);
#define adms_number_valueto_scalingunit(a,b) ((p_number)a)->_scalingunit=(b)
win32_interface void adms_number_valueto_scalingunit_impl (p_number mynumber,e_number_scalingunit _scalingunit);
#endif /* objectnumber_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectNumber.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectnumber_h
#define objectnumber_h
#include <admsObject/admsH.h>
#include <admsObject/objectSubexpression.h>
typedef enum {
  adms_number_enumeration_scalingunit_1,
  adms_number_enumeration_scalingunit_A,
  adms_number_enumeration_scalingunit_D,
  adms_number_enumeration_scalingunit_E,
  adms_number_enumeration_scalingunit_G,
  adms_number_enumeration_scalingunit_M,
  adms_number_enumeration_scalingunit_P,
  adms_number_enumeration_scalingunit_T,
  adms_number_enumeration_scalingunit_a,
  adms_number_enumeration_scalingunit_c,
  adms_number_enumeration_scalingunit_d,
  adms_number_enumeration_scalingunit_f,
  adms_number_enumeration_scalingunit_h,
  adms_number_enumeration_scalingunit_k,
  adms_number_enumeration_scalingunit_m,
  adms_number_enumeration_scalingunit_n,
  adms_number_enumeration_scalingunit_p,
  adms_number_enumeration_scalingunit_u
} e_number_scalingunit;
win32_interface char* adms_number_tostring_scalingunit_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_number_scalingunit adms_number_fromstring_scalingunit_impl (p_admsttransform myadmsttransform,char*token);
struct s_number {
  t_subexpression _subexpression;
  p_quark _value;
  int _value_isdefault : 1;
  p_enumeration _scalingunit;
  int _scalingunit_isdefault : 1;
};
#include <admsObject/objectQuark.h>
#include <admsObject/objectEnumeration.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_number_uid (p_number mynumber);
win32_interface int adms_number_cmp (p_number mynumber,p_number refnumber);
win32_interface p_number adms_number_new(p_quark myvalue);
win32_interface p_adms adms_number_new_impl (p_adms arguments[]);
#define adms_number(member) ((p_number) (member))
#define adms_number_isdefault_value(number) (adms_number(number)->_value_isdefault)
#define adms_number_valueof_value(number) (adms_number(number)->_value)
#define adms_number_isdefault_scalingunit(number) (adms_number(number)->_scalingunit_isdefault)
#define adms_number_valueof_scalingunit(number) (adms_number(number)->_scalingunit)
#define adms_number_valueof_subexpression(number) ((p_subexpression)number)
#define adms_number_valueof_math(number) ((p_math)number)
#define adms_number_valueof_adms(number) ((p_adms)number)
win32_interface inline void adms_number_valueto_value (p_number mynumber,p_quark _value);
win32_interface inline void adms_number_valueto_scalingunit (p_number mynumber,p_enumeration _scalingunit);
win32_interface inline void adms_number_free(p_number mynumber);
#endif /* objectnumber_h */
